csep.utils.stats.poisson\_joint\_log\_likelihood\_ndarray
=========================================================

.. currentmodule:: csep.utils.stats

.. autofunction:: poisson_joint_log_likelihood_ndarray